@@ -7,7 +7,7 @@ use Padre::Unload                            ();
 use Padre::Plugin::Nopaste::Services         ();
 use Padre::Plugin::Nopaste::FBP::Preferences ();
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 use parent qw(
 	Padre::Plugin::Nopaste::FBP::Preferences
 	Padre::Plugin
@@ -173,18 +173,20 @@ __END__
 
 =pod
 
+=encoding utf8
+
 =head1 NAME
 
 Padre::Plugin::Nopaste::Preferences - NoPaste plugin for Padre, The Perl IDE.
 
 =head1 VERSION
 
-version  0.06
+version: 0.07
 
 =head1 DESCRIPTION
 
-This module handles the Preferences dialogue window that is used to set your 
-chosen Nopaste Server and #Channel.
+This module handles the Preferences dialogue window that is used to set your
+ chosen Nopaste Server and #Channel.
 
 
 =head1 METHODS
@@ -195,7 +197,7 @@ chosen Nopaste Server and #Channel.
 
 	$self->{dialog} = Padre::Plugin::SpellCheck::Preferences->new( $self );
 
-Create and return a new dialogue window. 
+Create and return a new dialogue window.
 
 =item * on_server_chosen
 
@@ -238,24 +240,28 @@ Padre, Padre::Plugin::Nopaste::FBP::Preferences
 
 =head1 SEE ALSO
 
-For all related information (bug reporting, source code repository,
-etc.), refer to L<Padre::Plugin::Nopaste>.
+See L<Padre::Plugin::Nopaste>.
 
 =head1 AUTHOR
 
-Kevin Dawson E<lt>bowtie@cpan.orgE<gt>
+See L<Padre::Plugin::Nopaste>
 
-=head1 COPYRIGHT AND LICENSE
+=head2 CONTRIBUTORS
 
-Copyright (c) 2012 kevin dawson, all rights reserved.
+See L<Padre::Plugin::Nopaste>
 
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
+=head1 COPYRIGHT
+
+See L<Padre::Plugin::Nopaste>
+
+=head1 LICENSE
+
+See L<Padre::Plugin::Nopaste>
 
 =cut
 
 
-# Copyright 2008-2012 The Padre development team as listed in Padre.pm.
+# Copyright 2008-2013 The Padre development team as listed in Padre.pm.
 # LICENSE
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl 5 itself.
